#include <iostream>
#include <string>
#include <vector>
#include "memory_test.h"
#include "memory_Context.h"

extern memory_Context memory_createContext();

int main() {
  memory_createContext();
  std::cout
    << memory_test_generateConstPlayfield()
    << std::endl
    << memory_test_selectItem_1x()
    << std::endl
    << memory_test_selectItem_2x()
    << std::endl
    << memory_test_selectItem_3x()
    << std::endl
    << memory_test_shouldDeselectMismatchedItems()
    << std::endl
    << memory_test_shouldDeselectMismatchedItems_itemTwice()
    << std::endl
    << memory_test_shouldDetectVictory()
    << std::endl
    << memory_test_shouldHideMatchingItems()
    << std::endl
    ;
}
